import * as fs from "fs";
export declare function upload(url: string, data: Buffer): Promise<number>;
export declare function ll_to_wave(data: Buffer, channels: number): Buffer;
export interface WaveHeader {
    num_samples: number;
    num_channels: number;
    sample_rate: number;
    sample_format: "L16" | "L24" | "L32" | "Float";
}
export interface WaveFile {
    hdr: WaveHeader;
    read_raw: (sample: number) => number[];
    read_normalized: (sample: number) => number[];
}
export declare function normalize_l16(s: number): number;
export declare function normalize_l24(s: number): number;
export declare function read_wave_file(b: ArrayBuffer): WaveFile;
export declare function load_wave(path: fs.PathLike): WaveFile;
export declare function convert_wave_file(w: WaveFile, fmt: "L16" | "L24"): WaveFile;
export declare function truncate_wave_file(w: WaveFile, max_samples: number): {
    hdr: {
        num_samples: number;
        num_channels: number;
        sample_rate: number;
        sample_format: "L16" | "L24" | "L32" | "Float";
    };
    read_raw: (sample: number) => number[];
    read_normalized: (sample: number) => number[];
};
export declare function wave_file_replace_sample_rate(w: WaveFile, sample_rate: number): {
    hdr: {
        sample_rate: number;
        num_samples: number;
        num_channels: number;
        sample_format: "L16" | "L24" | "L32" | "Float";
    };
    read_raw: (sample: number) => number[];
    read_normalized: (sample: number) => number[];
};
export declare class WaveWriter {
    private fd;
    private pos;
    private buf;
    constructor(path: fs.PathLike);
    private static get_bits_per_sample;
    write_header(hdr: WaveHeader): void;
    write_data(w: WaveFile): void;
    close(): void;
}
export declare function write_wave_file(path: fs.PathLike, w: WaveFile): void;
export interface BIWHeader {
    Date: string;
    Time: string;
    Channels: number;
    BitDepth: number;
    SampleRate: number;
    SamplesPerChannel: number;
}
export interface BIW {
    header: BIWHeader;
    wave: WaveFile;
}
export declare function wave_file_to_biw(w: WaveFile): BIW;
export declare function encode_biw(b: BIW): Buffer;
