import * as VScript from "vscript";
export class ErrorCollector {
    vsocket;
    m_failures = [];
    constructor(vsocket) {
        this.vsocket = vsocket;
    }
    push(failure) {
        this.m_failures.push(failure);
    }
    collate() {
        const pertype = new Map();
        for (const failure of this.m_failures) {
            if (!pertype.has(failure.type))
                pertype.set(failure.type, []);
            VScript.enforce_nonnull(pertype.get(failure.type)).push(failure);
        }
        return pertype;
    }
    string_verdict() {
        const collated = this.collate();
        let result = "";
        {
            const access_denied = collated.get("access-denied");
            if (access_denied) {
                result += `Got ${access_denied.length} access control violation${access_denied.length > 1 ? "s" : ""}: ${access_denied.map((f) => VScript.DataViews.stringify_failure(f, this.vsocket))}\n`;
            }
        }
        {
            const uncreated = collated.get("create-row");
            if (uncreated) {
                result += `Failed to create ${uncreated.length} table rows: ${uncreated
                    .map((f) => {
                    VScript.enforce(f.type === "create-row");
                    return f.kwl;
                })
                    .sort((a, b) => a.localeCompare(b))}\n`;
            }
        }
        {
            const undeleted = collated.get("delete-rows");
            if (undeleted) {
                const rows = undeleted.flatMap((f) => {
                    VScript.enforce(f.type === "delete-rows");
                    return f.kwls;
                });
                result += `Failed to delete ${rows.length} row${rows.length > 1 ? "s" : ""}: ${rows.sort((a, b) => a.localeCompare(b)).join(", ")}\n`;
            }
        }
        {
            const unrenamed = collated.get("rename-row");
            for (const f of unrenamed ?? []) {
                VScript.enforce(f.type === "rename-row");
                result += `Failed to rename ${f.kwl} to ${f.name}\n`;
            }
        }
        {
            const unread = collated.get("read");
            if (unread) {
                result += `Got ${unread.length} read failure${unread.length > 1 ? "s" : ""}: ${unread
                    .map((f) => {
                    VScript.enforce(f.type === "read");
                    return `${f.kwl}.${f.kw}`;
                })
                    .sort((a, b) => a.localeCompare(b))
                    .join(", ")}\n`;
            }
        }
        {
            const unwritten = collated.get("write");
            if (unwritten) {
                result += `Got ${unwritten.length} write failure${unwritten.length > 1 ? "s" : ""}:\n${unwritten
                    .map((f) => {
                    VScript.enforce(f.type === "write");
                    return `${f.kwl}.${f.kw} -> ${JSON.stringify(f.payload)}`;
                })
                    .sort((a, b) => a.localeCompare(b))
                    .join(",\n  ")}\n`;
            }
        }
        {
            const wait_until_failures = collated.get("wait-until");
            if (wait_until_failures) {
                result += `Got ${wait_until_failures.length} wait_until failure${wait_until_failures.length > 1 ? "s" : ""}: ${wait_until_failures.map((f) => VScript.DataViews.stringify_failure(f, this.vsocket)).join(",\n  ")}\n`;
            }
        }
        return result.length === 0 ? null : result;
    }
}
